@@ -32,7 +32,8 @@ class _GroupBy(ImplementsArrayReduce):
         if any([np.issubdtype(m[c].dtype, np.number) for c in m]):
             if (meta == na_fill_value).any(axis=None):
                 raise ValueError(
-                    "na_fill_value conflicts with data value. Choose a na_fill_value not in meta"
+                    "na_fill_value conflicts with data value. Choose a na_fill_value "
+                    "not in meta"
                 )
             else:
                 m = m.fillna(na_fill_value)
@@ -78,12 +79,12 @@ class RunGroupBy(_GroupBy):
         """
         Apply a function to each group and append the results
 
-        `func` is called like `func(ar, *args, **kwargs)` for each :obj:`ScmRun` ``ar``
+        `func` is called like `func(ar, *args, **kwargs)` for each :class:`ScmRun <scmdata.run.ScmRun>` ``ar``
         in this group. If the result of this function call is None, than it is
         excluded from the results.
 
         The results are appended together using :func:`run_append`. The function
-        can change the size of the input :obj:`ScmRun` as long as :func:`run_append`
+        can change the size of the input :class:`ScmRun <scmdata.run.ScmRun>` as long as :func:`run_append`
         can be applied to all results.
 
         Examples
@@ -108,7 +109,7 @@ class RunGroupBy(_GroupBy):
 
         Returns
         -------
-        applied : :obj:`ScmRun`
+        applied : :class:`ScmRun <scmdata.run.ScmRun>`
             The result of splitting, applying and combining this array.
         """
         grouped = self._iter_grouped()
@@ -153,7 +154,7 @@ class RunGroupBy(_GroupBy):
 
         Returns
         -------
-        reduced : :obj:`ScmRun`
+        reduced : :class:`ScmRun <scmdata.run.ScmRun>`
             Array with summarized data and the indicated dimension(s)
             removed.
         """
