@@ -233,6 +233,8 @@ def plumeplot(  # pragma: no cover
     _plotted_lines = False
 
     quantile_labels = {}
+    plotted_hues = []
+    plotted_styles = []
     for q, alpha in quantiles_plumes:
         for hdf in _pdf.groupby(hue_var):
             hue_value = hdf.get_unique_meta(hue_var, no_duplicates=True)
@@ -240,6 +242,23 @@ def plumeplot(  # pragma: no cover
 
             for hsdf in hdf.groupby(style_var):
                 style_value = hsdf.get_unique_meta(style_var, no_duplicates=True)
+                quantiles = hsdf.get_unique_meta("quantile")
+
+                missing_quantile = False
+                for qt in q:
+                    if qt not in quantiles:
+                        warnings.warn(
+                            "Quantile {} not available for {} {}".format(
+                                qt, hue_value, style_value
+                            )
+                        )
+                        missing_quantile = True
+
+                if missing_quantile:
+                    continue
+
+                if hue_value not in plotted_hues:
+                    plotted_hues.append(hue_value)
 
                 xaxis = hsdf.timeseries(time_axis=time_axis).columns.tolist()
                 if palette is not None:
@@ -254,6 +273,7 @@ def plumeplot(  # pragma: no cover
 
                 if len(q) == 2:
                     label = "{:.0f}th - {:.0f}th".format(q[0] * 100, q[1] * 100)
+
                     p = ax.fill_between(
                         xaxis,
                         _get_1d_or_raise(
@@ -270,6 +290,9 @@ def plumeplot(  # pragma: no cover
                         _palette[hue_value] = p.get_facecolor()[0]
 
                 elif len(q) == 1:
+                    if style_value not in plotted_styles:
+                        plotted_styles.append(style_value)
+
                     _plotted_lines = True
 
                     if dashes is not None:
@@ -304,6 +327,9 @@ def plumeplot(  # pragma: no cover
                     if dashes is None:
                         _dashes[style_value] = p.get_linestyle()
 
+                    if palette is None:
+                        _palette[hue_value] = p.get_color()
+
                 else:
                     raise ValueError(
                         "quantiles to plot must be of length one or two, "
@@ -316,7 +342,7 @@ def plumeplot(  # pragma: no cover
     # Fake the line handles for the legend
     hue_val_lines = [
         mlines.Line2D([0], [0], color=_palette[hue_value], label=hue_value)
-        for hue_value in self.get_unique_meta(hue_var)
+        for hue_value in plotted_hues
     ]
 
     legend_items = [
@@ -336,7 +362,7 @@ def plumeplot(  # pragma: no cover
                 color="gray",
                 linewidth=linewidth,
             )
-            for style_value in self.get_unique_meta(style_var)
+            for style_value in plotted_styles
         ]
         legend_items += [
             mpatches.Patch(alpha=0, label=style_label),
