@@ -40,18 +40,14 @@ try:
             ]
             if any(not_datetime):
                 bad_values = self.data[not_datetime]["time"]
-                error_msg = "All time values must be convertible to datetime. The following values are not:\n{}".format(
-                    bad_values
+                error_msg = (
+                    "All time values must be convertible to datetime. The following "
+                    "values are not:\n{}".format(bad_values)
                 )
                 raise ValueError(error_msg)
 
 
-except ImportError:
+except ImportError:  # pragma: no cover
     # mypy can't work out try-except block sets typing
     IamDataFrame = None
     LongDatetimeIamDataFrame = None  # type: ignore
-
-try:
-    from matplotlib.axes import Axes  # pylint: disable=unused-import
-except ImportError:
-    Axes = None
