@@ -1,7 +1,8 @@
 """
 Time period handling and interpolation
 
-A large portion of this module was originally from openscm. Thanks to the original author, Sven Willner
+A large portion of this module was originally from openscm.
+Thanks to the original author, Sven Willner
 """
 
 from datetime import datetime
@@ -59,7 +60,7 @@ def _parse_datetime(inp: np.ndarray) -> np.ndarray:
 
 def _format_datetime(dts: np.ndarray) -> np.ndarray:
     """
-    Convert an array to an array of :class:`np.datetime64`.
+    Convert an array to an array of :class:`numpy.datetime64`.
 
     Parameters
     ----------
@@ -68,13 +69,13 @@ def _format_datetime(dts: np.ndarray) -> np.ndarray:
 
     Returns
     -------
-    :class:`np.ndarray` of :class:`np.datetime64`
+    :class:`numpy.ndarray` of :class:`numpy.datetime64`
         Converted array
 
     Raises
     ------
     ValueError
-        If one of the values in :obj:`dts` cannot be converted to :class:`np.datetime64`
+        If one of the values in :obj:`dts` cannot be converted to :class:`numpy.datetime64`
     """
     if len(dts) <= 0:  # pylint: disable=len-as-condition
         return np.array([], dtype=_TARGET_DTYPE)
@@ -95,7 +96,7 @@ def _format_datetime(dts: np.ndarray) -> np.ndarray:
 
 class TimePoints:
     """
-    Handles time points by wrapping :class:`np.ndarray` of :class:`np.datetime64`..
+    Handles time points by wrapping :class:`numpy.ndarray` of :class:`numpy.datetime64`..
     """
 
     def __init__(self, values):
@@ -124,27 +125,31 @@ class TimePoints:
 
     def to_index(self) -> pd.Index:
         """
-        Get time points as :class:`pd.Index`.
+        Get time points as :class:`pandas.Index`.
 
         Returns
         -------
-        :class:`pd.Index`
-            :class:`pd.Index` of :class:`np.dtype` :class:`object` with name ``"time"``
+        :class:`pandas.Index`
+            :class:`pandas.Index` of :class:`numpy.dtype` :class:`object` with name ``"time"``
             made from the time points represented as :class:`datetime.datetime`.
         """
         return pd.Index(self._values.astype(object), dtype=object, name="time")
 
-    def as_cftime(self) -> list:
+    def as_cftime(self, date_cls=cftime.DatetimeGregorian) -> list:
         """
-        Get as cftime datetimes
+        Format time points as :class:`cftime.datetime`
+
+        Parameters
+        ----------
+        date_cls : :class:`cftime.datetime`
+            The time points will be returned as instances of ``date_cls``
 
         Returns
         -------
-        list of cftime.datetime
+        list of :class:`cftime.datetime`
+            Time points as a list of ``date_cls`` objects
         """
-        return [
-            cftime.datetime(*dt.timetuple()[:6]) for dt in self._values.astype(object)
-        ]
+        return [date_cls(*dt.timetuple()[:6]) for dt in self._values.astype(object)]
 
     def years(self) -> np.ndarray:
         """
@@ -152,7 +157,7 @@ class TimePoints:
 
         Returns
         -------
-        :obj:`np.array` of :obj:`int`
+        :class:`numpy.ndarray` of :obj:`int`
             Year of each time point
         """
         return np.vectorize(getattr)(self._values.astype(object), "year")
@@ -163,7 +168,7 @@ class TimePoints:
 
         Returns
         -------
-        :obj:`np.array` of :obj:`int`
+        :class:`numpy.ndarray` of :obj:`int`
             Month of each time point
         """
         return np.vectorize(getattr)(self._values.astype(object), "month")
@@ -174,7 +179,7 @@ class TimePoints:
 
         Returns
         -------
-        :obj:`np.array` of :obj:`int`
+        :class:`numpy.ndarray` of :obj:`int`
             Day of each time point
         """
         return np.vectorize(getattr)(self._values.astype(object), "day")
@@ -185,7 +190,7 @@ class TimePoints:
 
         Returns
         -------
-        :obj:`np.array` of :obj:`int`
+        :class:`numpy.ndarray` of :obj:`int`
             Hour of each time point
         """
         return np.vectorize(getattr)(self._values.astype(object), "hour")
@@ -196,7 +201,7 @@ class TimePoints:
 
         Returns
         -------
-        :obj:`np.array` of :obj:`int`
+        :class:`numpy.ndarray` of :obj:`int`
             Day of the week of each time point
         """
         return np.vectorize(datetime.weekday)(self._values.astype(object))
